@@ -1,4 +1,4 @@
-from game import Tictactoe
+from src.tictactoe_marlene import Tictactoe
 
 
 def main():
